<template>
	<view class="spare_index">
		<scroll-view
			scroll-y="true"
			class="spare_index_scroll"
			:scroll-top="scrollTop" 
			refresher-enabled="true" 
			refresher-background="#EAEAEA"
			:refresher-triggered="triggered" 
			@refresherpulling="refresherrefresh"
			@scrolltolower="scrolltoLower">
			<view class="spare_card_index" v-for="(item,index) in auxiliaryDatas" :key="index">
				<view class="spare_card_header">{{item.assistName}}</view>
				<view class="spare_card_main">
					<view class="spare_card_left">
						<u-image src="@/static/auxiliary_phone.png" width="120rpx" height="120rpx"></u-image>
					</view>
					<view class="spare_card_right">
						<view class="spare_card_items">
							<view class="spare_card_titles">规格型号：</view>
							<view class="spare_card_datas">{{item.assistModel}}</view>
						</view>
						<view class="spare_card_items">
							<view class="spare_card_titles">类型：</view>
							<view class="spare_card_datas">{{item.dictName}}</view>
						</view>
						<view class="spare_card_items">
							<view class="spare_card_titles">库存：</view>
							<view class="spare_card_datas">{{item.stock}}</view>
						</view>
						<view class="spare_card_items">
							<view class="spare_card_titles">报警数：</view>
							<view class="spare_card_datas">{{item.alarmCount === null?'0':item.alarmCount}}</view>
						</view>
						<view class="spare_card_items">
							<view class="spare_card_titles">位置：</view>
							<view class="spare_card_datas">{{item.position}}</view>
						</view>
					</view>
				</view>
			</view>
			<u-loadmore :status="status" :icon-type="iconType" :load-text="loadText" />
		</scroll-view>
	</view>
</template>

<script>
	import { throttle } from '../../plugins/public.js';
	export default{
		data(){
			return{
				pageNum: 1,
				pageSize: 10,
				loadPage: 0,
				scrollTop: 0,
				triggered: true,
				status: 'loading',
				loadText: {
					loading: '努力加载中',
					nomore: '没有更多数据了'
				},
				auxiliaryDatas:[]
			}
		},
		onLoad() {
			this.searchAuxiliaryList()
		},
		methods:{
			//查询列表
			searchAuxiliaryList(){
				this.triggered = true;
				this.auxiliaryDatas = [];
				let params = {
					pageNum: this.pageNum,
					pageSize:this.pageSize,
				}
				this.$api.reboSystem.getAxiliaryLists(params).then(res=>{
					if(res.statusMsg === 'ok'){
						this.auxiliaryDatas = res.data.list
						this.loadPage = res.data.pages;
						this.triggered = false;
						this.status = 'nomore';
					}else{
						uni.$u.toast(res.statusMsg);
					}
				}).catch((err) => {
					uni.$u.toast('请检查网络服务或联系管理员！')
				})
			},
			//自定义下拉刷新
			refresherrefresh: throttle(function() {
				this.status = 'loading';
				this.pageNum = 1;
				this.searchAuxiliaryList();
				uni.$u.toast('刷新成功');
			}, 500),
			//触底刷新
			scrolltoLower: throttle(function() {
				this.status = 'loading';
				if(this.pageNum >= this.loadPage) {
					setTimeout(() => {
						this.status = 'nomore'
						uni.$u.toast('没有更多数据了');
					},1000)
					return
				} else {
					this.pageNum+=1
					let params = {
						pageNum: this.pageNum,
						pageSize:this.pageSize,
					}
					this.$api.reboSystem.getAxiliaryLists(params).then(res=>{
						if(res.statusMsg === 'ok'){
							this.auxiliaryDatas.push(...res.data.list)
							this.loadPage = res.data.pages;
							this.triggered = false;
							this.status = 'nomore';
						}else{
							uni.$u.toast(res.statusMsg);
						}
					}).catch((err) => {
						uni.$u.toast('请检查网络服务或联系管理员！')
					})
				}
			}, 1500),
		}
	}
</script>

<style scoped lang="scss">
	.spare_index{
		height: 100vh;
		padding: 10px 15px;
		background-color: #F6F6F6;
		.spare_index_scroll{
			height: 90%;
			
			.spare_card_index{
				height: 200px;
				background-color: #FFFFFF;
				border-radius: 6px;
				margin-bottom: 15px;
				
				.spare_card_header{
					border-bottom: 1px solid #EAEAEA;
					position: relative;
					line-height: 35px;
					padding-left: 15px;
					&::before{
						content: "";
						position: absolute;
						width: 3px;
						height: 16px;
						background-color: #1977FF;
						top: 10px;
						left: 8px;
					}
				}
				.spare_card_main{
					display: flex;
					margin-top: 15px;
					height: calc(100% - 51px);
					.spare_card_left{
						width: 30%;
						display: flex;
						justify-content: center;
						align-items: flex-start;
					}
					.spare_card_right{
						width: 70%;
						display: flex;
						flex-direction: column;
						padding-bottom: 10px;
						justify-content: space-between;
						.spare_card_items{
							display: flex;
							.spare_card_titles{
								flex: none;
								color: #999999;
								font-size: 15px;
							}
							.spare_card_datas{
								width: 230px;
								overflow: hidden;
								text-overflow: ellipsis;
								white-space: nowrap;
								color: 333333;
								font-size: 15px;
							}
						}
					}
				}
			}
		}
	}
</style>